wallaroo.wallaroo_ml_ops_api_client.models.assays_run_interactive_baseline_json_body_baseline_type_2 API documentation

# wallaroo.wallaroo_ml_ops_api_client.models.assays_run_interactive_baseline_json_body_baseline_type_2

View Source

     1from typing import Any, Dict, List, Type, TypeVar
     2
     3import attr
     4
     5from ..models.assays_run_interactive_baseline_json_body_baseline_type_2_sliding import \
     6    AssaysRunInteractiveBaselineJsonBodyBaselineType2Sliding
     7
     8T = TypeVar("T", bound="AssaysRunInteractiveBaselineJsonBodyBaselineType2")
     9
    10@attr.s(auto_attribs=True)
    11class AssaysRunInteractiveBaselineJsonBodyBaselineType2:
    12    """
    13    Attributes:
    14        sliding (AssaysRunInteractiveBaselineJsonBodyBaselineType2Sliding):
    15    """
    16
    17    sliding: AssaysRunInteractiveBaselineJsonBodyBaselineType2Sliding
    18    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    19
    20
    21    def to_dict(self) -> Dict[str, Any]:
    22        sliding = self.sliding.to_dict()
    23
    24
    25        field_dict: Dict[str, Any] = {}
    26        field_dict.update(self.additional_properties)
    27        field_dict.update({
    28            "Sliding": sliding,
    29        })
    30
    31        return field_dict
    32
    33
    34
    35    @classmethod
    36    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    37        d = src_dict.copy()
    38        sliding = AssaysRunInteractiveBaselineJsonBodyBaselineType2Sliding.from_dict(d.pop("Sliding"))
    39
    40
    41
    42
    43        assays_run_interactive_baseline_json_body_baseline_type_2 = cls(
    44            sliding=sliding,
    45        )
    46
    47        assays_run_interactive_baseline_json_body_baseline_type_2.additional_properties = d
    48        return assays_run_interactive_baseline_json_body_baseline_type_2
    49
    50    @property
    51    def additional_keys(self) -> List[str]:
    52        return list(self.additional_properties.keys())
    53
    54    def __getitem__(self, key: str) -> Any:
    55        return self.additional_properties[key]
    56
    57    def __setitem__(self, key: str, value: Any) -> None:
    58        self.additional_properties[key] = value
    59
    60    def __delitem__(self, key: str) -> None:
    61        del self.additional_properties[key]
    62
    63    def __contains__(self, key: str) -> bool:
    64        return key in self.additional_properties

@attr.s(auto_attribs=True)
class AssaysRunInteractiveBaselineJsonBodyBaselineType2: View Source

    11@attr.s(auto_attribs=True)
    12class AssaysRunInteractiveBaselineJsonBodyBaselineType2:
    13    """
    14    Attributes:
    15        sliding (AssaysRunInteractiveBaselineJsonBodyBaselineType2Sliding):
    16    """
    17
    18    sliding: AssaysRunInteractiveBaselineJsonBodyBaselineType2Sliding
    19    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    20
    21
    22    def to_dict(self) -> Dict[str, Any]:
    23        sliding = self.sliding.to_dict()
    24
    25
    26        field_dict: Dict[str, Any] = {}
    27        field_dict.update(self.additional_properties)
    28        field_dict.update({
    29            "Sliding": sliding,
    30        })
    31
    32        return field_dict
    33
    34
    35
    36    @classmethod
    37    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    38        d = src_dict.copy()
    39        sliding = AssaysRunInteractiveBaselineJsonBodyBaselineType2Sliding.from_dict(d.pop("Sliding"))
    40
    41
    42
    43
    44        assays_run_interactive_baseline_json_body_baseline_type_2 = cls(
    45            sliding=sliding,
    46        )
    47
    48        assays_run_interactive_baseline_json_body_baseline_type_2.additional_properties = d
    49        return assays_run_interactive_baseline_json_body_baseline_type_2
    50
    51    @property
    52    def additional_keys(self) -> List[str]:
    53        return list(self.additional_properties.keys())
    54
    55    def __getitem__(self, key: str) -> Any:
    56        return self.additional_properties[key]
    57
    58    def __setitem__(self, key: str, value: Any) -> None:
    59        self.additional_properties[key] = value
    60
    61    def __delitem__(self, key: str) -> None:
    62        del self.additional_properties[key]
    63
    64    def __contains__(self, key: str) -> bool:
    65        return key in self.additional_properties

Attributes: sliding (AssaysRunInteractiveBaselineJsonBodyBaselineType2Sliding):

AssaysRunInteractiveBaselineJsonBodyBaselineType2( sliding: wallaroo.wallaroo_ml_ops_api_client.models.assays_run_interactive_baseline_json_body_baseline_type_2_sliding.AssaysRunInteractiveBaselineJsonBodyBaselineType2Sliding) View Source

    2def __init__(self, sliding):
    3    self.sliding = sliding
    4    self.additional_properties = __attr_factory_additional_properties()

Method generated by attrs for class AssaysRunInteractiveBaselineJsonBodyBaselineType2.

def to_dict(self) -> Dict[str, Any]: View Source

    22    def to_dict(self) -> Dict[str, Any]:
    23        sliding = self.sliding.to_dict()
    24
    25
    26        field_dict: Dict[str, Any] = {}
    27        field_dict.update(self.additional_properties)
    28        field_dict.update({
    29            "Sliding": sliding,
    30        })
    31
    32        return field_dict

@classmethod
def from_dict(cls: Type[~T], src_dict: Dict[str, Any]) -> ~T: View Source

    36    @classmethod
    37    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    38        d = src_dict.copy()
    39        sliding = AssaysRunInteractiveBaselineJsonBodyBaselineType2Sliding.from_dict(d.pop("Sliding"))
    40
    41
    42
    43
    44        assays_run_interactive_baseline_json_body_baseline_type_2 = cls(
    45            sliding=sliding,
    46        )
    47
    48        assays_run_interactive_baseline_json_body_baseline_type_2.additional_properties = d
    49        return assays_run_interactive_baseline_json_body_baseline_type_2

additional_keys: List[str]